@@ -6,15 +6,13 @@ maxent_UI <- function(id) {
     "key: ", strong("L"), "inear, ", strong("Q"), "uadratic, ", strong("H"), "inge, ", strong("P"), "roduct, ", strong("T"), "hreshold",
     tags$div(title='Feature combinations to be explored. Features are constructed using different relationships within and among the environmental predictors, and are used to constrain the computed probability distribution. In short, more features = more potential model complexity.',
              checkboxGroupInput(ns("fcs"), label='',
-                       choices = list("L", "LQ", "H", "LQH", "LQHP", "LQHPT"), inline = TRUE)),
+                       choices = list("L", "LQ", "H", "LQH", "LQHP"), inline = TRUE)),
     strong("Select regularization multipliers "), strong(em("(penalty against complexity)")),
     tags$div(title='Range of regularization multipliers to explore. Greater values of the regularization multiplier lead to increased penalty against overly complex and/or overfit models. A value of 0 results in no regularization.',
              sliderInput(ns("rms"), label = "",
-                min = 0, max = 10, value = c(1, 2))),
+                min = 0.5, max = 10, step=0.5, value = c(1, 2))),
     tags$div(title='Value used to step through regularization multiplier range (e.g. range of 1-3 with step 0.5 results in [1, 1.5, 2, 2.5, 3]).',
-             numericInput(ns("rmsStep"), label = "Multiplier step value", value = 1)),
-    tags$div(title='If checked, the response will resist extrapolation to environmental values outside those used to build the model. See guidance for details.',
-             checkboxInput(ns('clamp'), label = 'Clamp predictions?'))
+             numericInput(ns("rmsStep"), label = "Multiplier step value", value = 1))
   )
 }
 
@@ -48,7 +46,6 @@ maxent_MOD <- function(input, output, session, rvs) {
     rvs$fcs <- input$fcs
     rvs$rms <- input$rms
     rvs$rmsStep <- input$rmsStep
-    rvs$clamp <- input$clamp
     
     # define the vector of RMs to input
     rms <- seq(input$rms[1], input$rms[2], input$rmsStep)  
@@ -75,7 +72,7 @@ maxent_MOD <- function(input, output, session, rvs) {
     e <- ENMeval::ENMevaluate(occs.xy, rvs$bgMsk, bg.coords = rvs$bgPts,
                               RMvalues = rms, fc = input$fcs, method = 'user', 
                               occ.grp = rvs$occsGrp, bg.grp = rvs$bgGrp, 
-                              clamp = input$clamp, bin.output = TRUE,
+                              bin.output = TRUE,
                               progbar = FALSE, updateProgress = updateProgress)
     
     names(e@models) <- e@results$settings
